#ifndef QRK_SOCKET_SET_H
#define QRK_SOCKET_SET_H

/*!
  \file
  \brief ʐM\PbgǗ

  \author Satofumi KAMIMURA

  $Id: SocketSet.h 1459 2009-10-26 21:36:20Z satofumi $
*/

#include <SDL_net.h>
#include <memory>

namespace qrk
{
  class TcpipCtrl;


  /*!
    \brief ʐM\PbgǗ
  */
  class SocketSet
  {
  public:
    /*!
      \brief RXgN^

      \param size [i] Ԃł̃\Pbge
    */
    explicit SocketSet(size_t size = 1);
    ~SocketSet(void);


    /*!
      \brief \Pbg̓o^

      \param socket [i] o^\Pbg

      \retval true o^ɐ
      \retval false o^Ɏs
    */
    bool add(TCPsocket socket);


    /*!
      \brief \Pbg̍폜

      \param socket [i] 폜\Pbg
    */
    void del(TCPsocket socket);


    /*!
      \brief Mf[^邩̊mF

      \param timeout [i] ^CAEg [msec]

      \return Mf[^̂\Pbg
    */
    size_t check(int timeout);

  private:
    SocketSet(const SocketSet& rhs);
    SocketSet& operator = (const SocketSet& rhs);

    struct pImpl;
    const std::auto_ptr<pImpl> pimpl;
  };
}

#endif /* !QRK_SOCKET_SET_H */
